Enum edges::Edges

source ·
pub enum Edges {
    DynamicImage(DynamicImage),
}

Variants



DynamicImage(DynamicImage)

Implementations

source

impl Edges

source

pub fn single_image_edge_translated(&self) -> Vec<Vec2>

If there’s only one sprite / object in the image, this returns just one, with coordinates translated to either side of (0, 0)

Examples found in repository?
examples/dynamic-image.rs (line 7)
4
5
6
7
8
fn main() {
    let image = image::open(Path::new("assets/car.png"));
    let edges = Edges::from(image.unwrap());
    println!("{:#?}", edges.single_image_edge_translated());
}
source

pub fn single_image_edge_raw(&self) -> Vec<Vec2>

If there’s only one sprite / object in the image, this returns just one, with coordinates left alone and all in positive x and y

source

pub fn multi_image_edge_translated(&self) -> Vec<Vec<Vec2>>

If there’s more than one sprite / object in the image, this returns all it finds, with coordinates translated to either side of (0, 0)

source

pub fn multi_image_edges_raw(&self) -> Vec<Vec<Vec2>>

If there’s more than one sprite / object in the image, this returns all it finds, with coordinates left alone and all in positive x and y

source

pub fn image_edges(&self, translate: bool) -> Vec<Vec<Vec2>>

Takes a Bevy DynamicImage type and an boolean to indicate whether to translate the points you get back to either side of (0, 0) instead of everything in positive x and y

source

pub fn march_edges( data: &[usize], rows: usize, cols: usize, translate: bool ) -> Vec<Vec<Vec2>>

Marching squares adjacent, walks all the pixels in the provided data and keeps track of any that have at least one transparent / zero value neighbor then, while sorting into drawing order, groups them into sets of connected pixels

Accepts a flag indicating whether or not to translate coordinates to either side of (0,0) or leave it all in positive x,y

source

pub fn translate_vec(v: Vec<Vec2>, rows: usize, cols: usize) -> Vec<Vec2>

Translate vector of points in positive x,y to either side of (0,0)